@@ -2,6 +2,14 @@ When /^I set my HTTParty timeout option to (\d+)$/ do |timeout|
   @request_options[:timeout] = timeout.to_i
 end
 
+When /^I set my HTTParty open_timeout option to (\d+)$/ do |timeout|
+  @request_options[:open_timeout] = timeout.to_i
+end
+
+When /^I set my HTTParty read_timeout option to (\d+)$/ do |timeout|
+  @request_options[:read_timeout] = timeout.to_i
+end
+
 When /I call HTTParty#get with '(.*)'$/ do |url|
   begin
     @response_from_httparty = HTTParty.get("http://#{@host_and_port}#{url}", @request_options)
@@ -22,7 +30,7 @@ When /I call HTTParty#get with '(.*)' and a basic_auth hash:/ do |url, auth_tabl
   h = auth_table.hashes.first
   @response_from_httparty = HTTParty.get(
     "http://#{@host_and_port}#{url}",
-    :basic_auth => { :username => h["username"], :password => h["password"] }
+    basic_auth: { username: h["username"], password: h["password"] }
   )
 end
 
@@ -30,6 +38,6 @@ When /I call HTTParty#get with '(.*)' and a digest_auth hash:/ do |url, auth_tab
   h = auth_table.hashes.first
   @response_from_httparty = HTTParty.get(
     "http://#{@host_and_port}#{url}",
-    :digest_auth => { :username => h["username"], :password => h["password"] }
+    digest_auth: { username: h["username"], password: h["password"] }
   )
 end
