@@ -1,6 +1,6 @@
 Given /a remote service that returns '(.*)'/ do |response_body|
   @handler = BasicMongrelHandler.new
-  Given "the response from the service has a body of '#{response_body}'"
+  step "the response from the service has a body of '#{response_body}'"
 end
 
 Given /^a remote service that returns:$/ do |response_body|
@@ -19,13 +19,18 @@ end
 
 Given /^that service takes (\d+) seconds to generate a response$/ do |time|
   @server_response_time = time.to_i
-  @handler.preprocessor = Proc.new { sleep time.to_i }
+  @handler.preprocessor = proc { sleep time.to_i }
 end
 
 Given /^a remote deflate service$/ do
   @handler = DeflateHandler.new
 end
 
+Given /^a remote deflate service on port '(\d+)'/ do |port|
+  run_server(port)
+  @handler = DeflateHandler.new
+end
+
 Given /^a remote gzip service$/ do
   @handler = GzipHandler.new
 end
@@ -55,11 +60,18 @@ Given /that service requires the username '(.*)' with the password '(.*)'/ do |u
   @handler.password = password
 end
 
+# customize aruba cucumber step
+Then /^the output should contain '(.*)'$/ do |expected|
+  assert_partial_output(expected, all_output)
+end
+
 Given /a restricted page at '(.*)'/ do |url|
-  Given "a remote service that returns 'A response I will never see'"
-  And "that service is accessed at the path '#{url}'"
-  And "that service is protected by Basic Authentication"
-  And "that service requires the username 'something' with the password 'secret'"
+  steps "
+    Given a remote service that returns 'A response I will never see'
+    And that service is accessed at the path '#{url}'
+    And that service is protected by Basic Authentication
+    And that service requires the username 'something' with the password 'secret'
+  "
 end
 
 # This joins the server thread, and halts cucumber, so you can actually hit the
