@@ -6,6 +6,7 @@ require 'zlib'
 require 'multi_xml'
 require 'json'
 require 'csv'
+require 'erb'
 
 require 'httparty/module_inheritable_attributes'
 require 'httparty/cookie_hash'
@@ -16,22 +17,9 @@ require 'httparty/logger/logger'
 
 # @see HTTParty::ClassMethods
 module HTTParty
-  module AllowedFormatsDeprecation
-    def const_missing(const)
-      if const.to_s =~ /AllowedFormats$/
-        Kernel.warn("Deprecated: Use HTTParty::Parser::SupportedFormats")
-        HTTParty::Parser::SupportedFormats
-      else
-        super
-      end
-    end
-  end
-
-  extend AllowedFormatsDeprecation
-
   def self.included(base)
     base.extend ClassMethods
-    base.send :include, HTTParty::ModuleInheritableAttributes
+    base.send :include, ModuleInheritableAttributes
     base.send(:mattr_inheritable, :default_options)
     base.send(:mattr_inheritable, :default_cookies)
     base.instance_variable_set("@default_options", {})
@@ -41,13 +29,13 @@ module HTTParty
   # == Common Request Options
   # Request methods (get, post, patch, put, delete, head, options) all take a common set of options. These are:
   #
-  # [:+body+:] Body of the request. If passed a Hash, will try to normalize it first, by default passing it to ActiveSupport::to_params. Any other kind of object will get used as-is.
+  # [:+body+:] Body of the request. If passed an object that responds to #to_hash, will try to normalize it first, by default passing it to ActiveSupport::to_params. Any other kind of object will get used as-is.
   # [:+http_proxyaddr+:] Address of proxy server to use.
   # [:+http_proxyport+:]  Port of proxy server to use.
   # [:+http_proxyuser+:] User for proxy server authentication.
   # [:+http_proxypass+:] Password for proxy server authentication.
   # [:+limit+:] Maximum number of redirects to follow. Takes precedences over :+no_follow+.
-  # [:+query+:] Query string, or a Hash representing it. Normalized according to the same rules as :+body+. If you specify this on a POST, you must use a Hash. See also HTTParty::ClassMethods.default_params.
+  # [:+query+:] Query string, or an object that responds to #to_hash representing it. Normalized according to the same rules as :+body+. If you specify this on a POST, you must use an object which responds to #to_hash. See also HTTParty::ClassMethods.default_params.
   # [:+timeout+:] Timeout for opening connection and reading data.
   # [:+local_host:] Local address to bind to before connecting.
   # [:+local_port:] Local port to bind to before connecting.
@@ -58,7 +46,7 @@ module HTTParty
   # * :+debug_output+: see HTTParty::ClassMethods.debug_output.
   # * :+digest_auth+: see HTTParty::ClassMethods.digest_auth. Only one of :+basic_auth+ and :+digest_auth+ can be used at a time; if you try using both, you'll get an ArgumentError.
   # * :+format+: see HTTParty::ClassMethods.format.
-  # * :+headers+: see HTTParty::ClassMethods.headers. Must be a Hash.
+  # * :+headers+: see HTTParty::ClassMethods.headers. Must be a an object which responds to #to_hash.
   # * :+maintain_method_across_redirects+: see HTTParty::ClassMethods.maintain_method_across_redirects.
   # * :+no_follow+: see HTTParty::ClassMethods.no_follow.
   # * :+parser+: see HTTParty::ClassMethods.parser.
@@ -69,16 +57,13 @@ module HTTParty
   # * :+ssl_ca_path+: see HTTParty::ClassMethods.ssl_ca_path.
 
   module ClassMethods
-
-    extend AllowedFormatsDeprecation
-
     # Turns on logging
     #
     #   class Foo
     #     include HTTParty
     #     logger Logger.new('http_logger'), :info, :apache
     #   end
-    def logger(logger, level=:info, format=:apache)
+    def logger(logger, level = :info, format = :apache)
       default_options[:logger]     = logger
       default_options[:log_level]  = level
       default_options[:log_format] = format
@@ -90,7 +75,7 @@ module HTTParty
     #     include HTTParty
     #     http_proxy 'http://foo.com', 80, 'user', 'pass'
     #   end
-    def http_proxy(addr=nil, port=nil, user=nil, pass=nil)
+    def http_proxy(addr = nil, port = nil, user = nil, pass = nil)
       default_options[:http_proxyaddr] = addr
       default_options[:http_proxyport] = port
       default_options[:http_proxyuser] = user
@@ -104,7 +89,7 @@ module HTTParty
     #     include HTTParty
     #     base_uri 'twitter.com'
     #   end
-    def base_uri(uri=nil)
+    def base_uri(uri = nil)
       return default_options[:base_uri] unless uri
       default_options[:base_uri] = HTTParty.normalize_base_uri(uri)
     end
@@ -116,7 +101,7 @@ module HTTParty
     #     basic_auth 'username', 'password'
     #   end
     def basic_auth(u, p)
-      default_options[:basic_auth] = {:username => u, :password => p}
+      default_options[:basic_auth] = {username: u, password: p}
     end
 
     # Allows setting digest authentication username and password.
@@ -126,14 +111,14 @@ module HTTParty
     #     digest_auth 'username', 'password'
     #   end
     def digest_auth(u, p)
-      default_options[:digest_auth] = {:username => u, :password => p}
+      default_options[:digest_auth] = {username: u, password: p}
     end
 
     # Do not send rails style query strings.
     # Specically, don't use bracket notation when sending an array
     #
     # For a query:
-    #   get '/', :query => {:selected_ids => [1,2,3]}
+    #   get '/', query: {selected_ids: [1,2,3]}
     #
     # The default query string looks like this:
     #   /?selected_ids[]=1&selected_ids[]=2&selected_ids[]=3
@@ -156,10 +141,10 @@ module HTTParty
     #
     #   class Foo
     #     include HTTParty
-    #     default_params :api_key => 'secret', :another => 'foo'
+    #     default_params api_key: 'secret', another: 'foo'
     #   end
-    def default_params(h={})
-      raise ArgumentError, 'Default params must be a hash' unless h.is_a?(Hash)
+    def default_params(h = {})
+      raise ArgumentError, 'Default params must an object which respond to #to_hash' unless h.respond_to?(:to_hash)
       default_options[:default_params] ||= {}
       default_options[:default_params].merge!(h)
     end
@@ -176,6 +161,28 @@ module HTTParty
       default_options[:timeout] = t
     end
 
+    # Allows setting a default open_timeout for all HTTP calls in seconds
+    #
+    #   class Foo
+    #     include HTTParty
+    #     open_timeout 10
+    #   end
+    def open_timeout(t)
+      raise ArgumentError, 'open_timeout must be an integer or float' unless t && (t.is_a?(Integer) || t.is_a?(Float))
+      default_options[:open_timeout] = t
+    end
+
+    # Allows setting a default read_timeout for all HTTP calls in seconds
+    #
+    #   class Foo
+    #     include HTTParty
+    #     read_timeout 10
+    #   end
+    def read_timeout(t)
+      raise ArgumentError, 'read_timeout must be an integer or float' unless t && (t.is_a?(Integer) || t.is_a?(Float))
+      default_options[:read_timeout] = t
+    end
+
     # Set an output stream for debugging, defaults to $stderr.
     # The output stream is passed on to Net::HTTP#set_debug_output.
     #
@@ -193,14 +200,14 @@ module HTTParty
     #     include HTTParty
     #     headers 'Accept' => 'text/html'
     #   end
-    def headers(h={})
-      raise ArgumentError, 'Headers must be a hash' unless h.is_a?(Hash)
+    def headers(h = {})
+      raise ArgumentError, 'Headers must an object which responds to #to_hash' unless h.respond_to?(:to_hash)
       default_options[:headers] ||= {}
-      default_options[:headers].merge!(h)
+      default_options[:headers].merge!(h.to_hash)
     end
 
-    def cookies(h={})
-      raise ArgumentError, 'Cookies must be a hash' unless h.is_a?(Hash)
+    def cookies(h = {})
+      raise ArgumentError, 'Cookies must an object which respond to #to_hash' unless h.respond_to?(:to_hash)
       default_cookies.add_cookies(h)
     end
 
@@ -272,13 +279,31 @@ module HTTParty
       default_options[:maintain_method_across_redirects] = value
     end
 
+    # Declare that you wish to resend the full HTTP request across redirects,
+    # even on redirects that should logically become GET requests.
+    # A 303 redirect in HTTP signifies that the redirected url should normally
+    # retrieved using a GET request, for instance, it is the output of a previous
+    # POST. maintain_method_across_redirects respects this behavior, but you
+    # can force HTTParty to resend_on_redirect even on 303 responses.
+    #
+    # @example
+    #   class Foo
+    #     include HTTParty
+    #     base_uri 'http://google.com'
+    #     resend_on_redirect
+    #   end
+
+    def resend_on_redirect(value = true)
+      default_options[:resend_on_redirect] = value
+    end
+
     # Allows setting a PEM file to be used
     #
     #   class Foo
     #     include HTTParty
     #     pem File.read('/home/user/my.pem'), "optional password"
     #   end
-    def pem(pem_contents, password=nil)
+    def pem(pem_contents, password = nil)
       default_options[:pem] = pem_contents
       default_options[:pem_password] = password
     end
@@ -298,7 +323,7 @@ module HTTParty
     # Helpful for overriding the default rails normalization of Array queries.
     #
     # For a query:
-    #   get '/', :query => {:selected_ids => [1,2,3]}
+    #   get '/', query: {selected_ids: [1,2,3]}
     #
     # The default query string normalizer returns:
     #   /?selected_ids[]=1&selected_ids[]=2&selected_ids[]=3
@@ -406,7 +431,7 @@ module HTTParty
     # @example provide optional configuration for your connection_adapter
     #   class Foo
     #     include HTTParty
-    #     connection_adapter Proc.new {|uri, options| ... }, {:foo => :bar}
+    #     connection_adapter Proc.new {|uri, options| ... }, {foo: :bar}
     #   end
     #
     # @see HTTParty::ConnectionAdapter
@@ -430,8 +455,8 @@ module HTTParty
     #
     #   # Simple get with full url and query parameters
     #   # ie: http://foo.com/resource.json?limit=10
-    #   Foo.get('http://foo.com/resource.json', :query => {:limit => 10})
-    def get(path, options={}, &block)
+    #   Foo.get('http://foo.com/resource.json', query: {limit: 10})
+    def get(path, options = {}, &block)
       perform_request Net::HTTP::Get, path, options, &block
     end
 
@@ -442,80 +467,78 @@ module HTTParty
     #   end
     #
     #   # Simple post with full url and setting the body
-    #   Foo.post('http://foo.com/resources', :body => {:bar => 'baz'})
+    #   Foo.post('http://foo.com/resources', body: {bar: 'baz'})
     #
     #   # Simple post with full url using :query option,
     #   # which gets set as form data on the request.
-    #   Foo.post('http://foo.com/resources', :query => {:bar => 'baz'})
-    def post(path, options={}, &block)
+    #   Foo.post('http://foo.com/resources', query: {bar: 'baz'})
+    def post(path, options = {}, &block)
       perform_request Net::HTTP::Post, path, options, &block
     end
 
     # Perform a PATCH request to a path
-    def patch(path, options={}, &block)
+    def patch(path, options = {}, &block)
       perform_request Net::HTTP::Patch, path, options, &block
     end
 
     # Perform a PUT request to a path
-    def put(path, options={}, &block)
+    def put(path, options = {}, &block)
       perform_request Net::HTTP::Put, path, options, &block
     end
 
     # Perform a DELETE request to a path
-    def delete(path, options={}, &block)
+    def delete(path, options = {}, &block)
       perform_request Net::HTTP::Delete, path, options, &block
     end
 
     # Perform a MOVE request to a path
-    def move(path, options={}, &block)
+    def move(path, options = {}, &block)
       perform_request Net::HTTP::Move, path, options, &block
     end
 
     # Perform a COPY request to a path
-    def copy(path, options={}, &block)
+    def copy(path, options = {}, &block)
       perform_request Net::HTTP::Copy, path, options, &block
     end
 
     # Perform a HEAD request to a path
-    def head(path, options={}, &block)
+    def head(path, options = {}, &block)
       perform_request Net::HTTP::Head, path, options, &block
     end
 
     # Perform an OPTIONS request to a path
-    def options(path, options={}, &block)
+    def options(path, options = {}, &block)
       perform_request Net::HTTP::Options, path, options, &block
     end
 
-    def default_options #:nodoc:
-      @default_options
-    end
+    attr_reader :default_options
 
     private
 
-      def perform_request(http_method, path, options, &block) #:nodoc:
-        options = default_options.merge(options)
-        process_headers(options)
-        process_cookies(options)
-        Request.new(http_method, path, options).perform(&block)
-      end
+    def perform_request(http_method, path, options, &block) #:nodoc:
+      options = ModuleInheritableAttributes.hash_deep_dup(default_options).merge(options)
+      process_headers(options)
+      process_cookies(options)
+      Request.new(http_method, path, options).perform(&block)
+    end
 
-      def process_headers(options)
-        if options[:headers] && headers.any?
-          options[:headers] = headers.merge(options[:headers])
-        end
+    def process_headers(options)
+      if options[:headers] && headers.any?
+        options[:headers] = headers.merge(options[:headers])
       end
+    end
 
-      def process_cookies(options) #:nodoc:
-        return unless options[:cookies] || default_cookies.any?
-        options[:headers] ||= headers.dup
-        options[:headers]["cookie"] = cookies.merge(options.delete(:cookies) || {}).to_cookie_string
-      end
+    def process_cookies(options) #:nodoc:
+      return unless options[:cookies] || default_cookies.any?
+      options[:headers] ||= headers.dup
+      options[:headers]["cookie"] = cookies.merge(options.delete(:cookies) || {}).to_cookie_string
+    end
 
-      def validate_format
-        if format && parser.respond_to?(:supports_format?) && !parser.supports_format?(format)
-          raise UnsupportedFormat, "'#{format.inspect}' Must be one of: #{parser.supported_formats.map{|f| f.to_s}.sort.join(', ')}"
-        end
+    def validate_format
+      if format && parser.respond_to?(:supports_format?) && !parser.supports_format?(format)
+        raise UnsupportedFormat, "'#{format.inspect}' Must be one of: #{parser.supported_formats.map(&:to_s).sort.join(', ')}"
       end
+    end
   end
 
   def self.normalize_base_uri(url) #:nodoc:
@@ -570,7 +593,6 @@ module HTTParty
   end
 end
 
-require 'httparty/core_extensions'
 require 'httparty/hash_conversions'
 require 'httparty/exceptions'
 require 'httparty/parser'
