@@ -38,15 +38,18 @@ module HTTParty
   # in the #options attribute. It is up to you to interpret them within your
   # connection adapter. Take a look at the implementation of
   # HTTParty::ConnectionAdapter#connection for examples of how they are used.
-  # Something are probably interesting are as follows:
+  # Some things that are probably interesting are as follows:
   # * :+timeout+: timeout in seconds
+  # * :+open_timeout+: http connection open_timeout in seconds, overrides timeout if set
+  # * :+read_timeout+: http connection read_timeout in seconds, overrides timeout if set
   # * :+debug_output+: see HTTParty::ClassMethods.debug_output.
   # * :+pem+: contains pem data. see HTTParty::ClassMethods.pem.
+  # * :+verify+: verify the server’s certificate against the ca certificate.
+  # * :+verify_peer+: set to false to turn off server verification but still send client certificate
   # * :+ssl_ca_file+: see HTTParty::ClassMethods.ssl_ca_file.
   # * :+ssl_ca_path+: see HTTParty::ClassMethods.ssl_ca_path.
-  # * :+connection_adapter_options+: contains the hash your passed to HTTParty.connection_adapter when you configured your connection adapter
+  # * :+connection_adapter_options+: contains the hash you passed to HTTParty.connection_adapter when you configured your connection adapter
   class ConnectionAdapter
-
     # Private: Regex used to strip brackets from IPv6 URIs.
     StripIpv6BracketsRegex = /\A\[(.*)\]\z/
 
@@ -57,8 +60,8 @@ module HTTParty
 
     attr_reader :uri, :options
 
-    def initialize(uri, options={})
-      raise ArgumentError, "uri must be a URI, not a #{uri.class}" unless uri.kind_of? URI
+    def initialize(uri, options = {})
+      raise ArgumentError, "uri must be a URI, not a #{uri.class}" unless uri.is_a? URI
 
       @uri = uri
       @options = options
@@ -81,6 +84,14 @@ module HTTParty
         http.read_timeout = options[:timeout]
       end
 
+      if options[:read_timeout] && (options[:read_timeout].is_a?(Integer) || options[:read_timeout].is_a?(Float))
+        http.read_timeout = options[:read_timeout]
+      end
+
+      if options[:open_timeout] && (options[:open_timeout].is_a?(Integer) || options[:open_timeout].is_a?(Float))
+        http.open_timeout = options[:open_timeout]
+      end
+
       if options[:debug_output]
         http.set_debug_output(options[:debug_output])
       end
@@ -108,7 +119,7 @@ module HTTParty
         end
       end
 
-      return http
+      http
     end
 
     private
@@ -141,10 +152,11 @@ module HTTParty
         end
 
         # Client certificate authentication
+        # Note: options[:pem] must contain the content of a PEM file having the private key appended
         if options[:pem]
           http.cert = OpenSSL::X509::Certificate.new(options[:pem])
           http.key = OpenSSL::PKey::RSA.new(options[:pem], options[:pem_password])
-          http.verify_mode = OpenSSL::SSL::VERIFY_PEER
+          http.verify_mode = options[:verify_peer] == false ? OpenSSL::SSL::VERIFY_NONE : OpenSSL::SSL::VERIFY_PEER
         end
 
         # PKCS12 client certificate authentication
@@ -152,7 +164,7 @@ module HTTParty
           p12 = OpenSSL::PKCS12.new(options[:p12], options[:p12_password])
           http.cert = p12.certificate
           http.key = p12.key
-          http.verify_mode = OpenSSL::SSL::VERIFY_PEER
+          http.verify_mode = options[:verify_peer] == false ? OpenSSL::SSL::VERIFY_NONE : OpenSSL::SSL::VERIFY_PEER
         end
 
         # SSL certificate authority file and/or directory
