@@ -4,8 +4,8 @@ require 'httparty/logger/curl_logger'
 module HTTParty
   module Logger
     def self.build(logger, level, formatter)
-      level  ||= :info
-      format ||= :apache
+      level ||= :info
+      formatter ||= :apache
 
       case formatter
       when :curl
