@@ -1,11 +1,11 @@
 require File.expand_path(File.join(File.dirname(__FILE__), '..', 'spec_helper'))
 
-describe Net::HTTPHeader::DigestAuthenticator do
+RSpec.describe Net::HTTPHeader::DigestAuthenticator do
   def setup_digest(response)
     digest = Net::HTTPHeader::DigestAuthenticator.new("Mufasa",
-      "Circle Of Life", "GET", "/dir/index.html", response)
-    digest.stub(:random).and_return("deadbeef")
-    Digest::MD5.stub(:hexdigest) { |str| "md5(#{str})" }
+                                                      "Circle Of Life", "GET", "/dir/index.html", response)
+    allow(digest).to receive(:random).and_return("deadbeef")
+    allow(Digest::MD5).to receive(:hexdigest) { |str| "md5(#{str})" }
     digest
   end
 
@@ -13,6 +13,34 @@ describe Net::HTTPHeader::DigestAuthenticator do
     @digest.authorization_header.join(", ")
   end
 
+  def cookie_header
+    @digest.cookie_header
+  end
+
+  context "with a cookie value in the response header" do
+    before do
+      @digest = setup_digest({
+        'www-authenticate' => 'Digest realm="myhost@testrealm.com"',
+        'Set-Cookie' => 'custom-cookie=1234567'
+      })
+    end
+
+    it "should set cookie header" do
+      expect(cookie_header).to include('custom-cookie=1234567')
+    end
+  end
+
+  context "without a cookie value in the response header" do
+    before do
+      @digest = setup_digest({
+        'www-authenticate' => 'Digest realm="myhost@testrealm.com"'
+      })
+    end
+
+    it "should set empty cookie header array" do
+      expect(cookie_header).to eql []
+    end
+  end
 
   context "with an opaque value in the response header" do
     before do
@@ -22,7 +50,7 @@ describe Net::HTTPHeader::DigestAuthenticator do
     end
 
     it "should set opaque" do
-      authorization_header.should include(%Q(opaque="solid"))
+      expect(authorization_header).to include('opaque="solid"')
     end
   end
 
@@ -34,119 +62,130 @@ describe Net::HTTPHeader::DigestAuthenticator do
     end
 
     it "should not set opaque" do
-      authorization_header.should_not include(%Q(opaque=))
+      expect(authorization_header).not_to include("opaque=")
     end
   end
 
   context "with specified quality of protection (qop)" do
     before do
       @digest = setup_digest({
-        'www-authenticate' => 'Digest realm="myhost@testrealm.com", nonce="NONCE", qop="auth"',
+        'www-authenticate' => 'Digest realm="myhost@testrealm.com", nonce="NONCE", qop="auth"'
       })
     end
 
     it "should set prefix" do
-      authorization_header.should =~ /^Digest /
+      expect(authorization_header).to match(/^Digest /)
     end
 
     it "should set username" do
-      authorization_header.should include(%Q(username="Mufasa"))
+      expect(authorization_header).to include('username="Mufasa"')
     end
 
     it "should set digest-uri" do
-      authorization_header.should include(%Q(uri="/dir/index.html"))
+      expect(authorization_header).to include('uri="/dir/index.html"')
     end
 
     it "should set qop" do
-      authorization_header.should include(%Q(qop="auth"))
+      expect(authorization_header).to include('qop="auth"')
     end
 
     it "should set cnonce" do
-      authorization_header.should include(%Q(cnonce="md5(deadbeef)"))
+      expect(authorization_header).to include('cnonce="md5(deadbeef)"')
     end
 
     it "should set nonce-count" do
-      authorization_header.should include(%Q(nc=00000001))
+      expect(authorization_header).to include("nc=00000001")
     end
 
     it "should set response" do
       request_digest = "md5(md5(Mufasa:myhost@testrealm.com:Circle Of Life):NONCE:00000001:md5(deadbeef):auth:md5(GET:/dir/index.html))"
-      authorization_header.should include(%Q(response="#{request_digest}"))
+      expect(authorization_header).to include(%(response="#{request_digest}"))
     end
   end
 
+  context "when quality of protection (qop) is unquoted" do
+    before do
+      @digest = setup_digest({
+        'www-authenticate' => 'Digest realm="myhost@testrealm.com", nonce="NONCE", qop=auth'
+      })
+    end
+
+    it "should still set qop" do
+      expect(authorization_header).to include('qop="auth"')
+    end
+  end
 
   context "with unspecified quality of protection (qop)" do
     before do
       @digest = setup_digest({
-        'www-authenticate' => 'Digest realm="myhost@testrealm.com", nonce="NONCE"',
+        'www-authenticate' => 'Digest realm="myhost@testrealm.com", nonce="NONCE"'
       })
     end
 
     it "should set prefix" do
-      authorization_header.should =~ /^Digest /
+      expect(authorization_header).to match(/^Digest /)
     end
 
     it "should set username" do
-      authorization_header.should include(%Q(username="Mufasa"))
+      expect(authorization_header).to include('username="Mufasa"')
     end
 
     it "should set digest-uri" do
-      authorization_header.should include(%Q(uri="/dir/index.html"))
+      expect(authorization_header).to include('uri="/dir/index.html"')
     end
 
     it "should not set qop" do
-      authorization_header.should_not include(%Q(qop=))
+      expect(authorization_header).not_to include("qop=")
     end
 
     it "should not set cnonce" do
-      authorization_header.should_not include(%Q(cnonce=))
+      expect(authorization_header).not_to include("cnonce=")
     end
 
     it "should not set nonce-count" do
-      authorization_header.should_not include(%Q(nc=))
+      expect(authorization_header).not_to include("nc=")
     end
 
     it "should set response" do
       request_digest = "md5(md5(Mufasa:myhost@testrealm.com:Circle Of Life):NONCE:md5(GET:/dir/index.html))"
-      authorization_header.should include(%Q(response="#{request_digest}"))
+      expect(authorization_header).to include(%(response="#{request_digest}"))
     end
   end
 
   context "with multiple authenticate headers" do
     before do
       @digest = setup_digest({
-        'www-authenticate' => 'NTLM, Digest realm="myhost@testrealm.com", nonce="NONCE", qop="auth"',
+        'www-authenticate' => 'NTLM, Digest realm="myhost@testrealm.com", nonce="NONCE", qop="auth"'
       })
     end
 
     it "should set prefix" do
-      authorization_header.should =~ /^Digest /
+      expect(authorization_header).to match(/^Digest /)
     end
 
     it "should set username" do
-      authorization_header.should include(%Q(username="Mufasa"))
+      expect(authorization_header).to include('username="Mufasa"')
     end
 
     it "should set digest-uri" do
-      authorization_header.should include(%Q(uri="/dir/index.html"))
+      expect(authorization_header).to include('uri="/dir/index.html"')
     end
 
     it "should set qop" do
-      authorization_header.should include(%Q(qop="auth"))
+      expect(authorization_header).to include('qop="auth"')
     end
 
     it "should set cnonce" do
-      authorization_header.should include(%Q(cnonce="md5(deadbeef)"))
+      expect(authorization_header).to include('cnonce="md5(deadbeef)"')
     end
 
     it "should set nonce-count" do
-      authorization_header.should include(%Q(nc=00000001))
+      expect(authorization_header).to include("nc=00000001")
     end
 
     it "should set response" do
       request_digest = "md5(md5(Mufasa:myhost@testrealm.com:Circle Of Life):NONCE:00000001:md5(deadbeef):auth:md5(GET:/dir/index.html))"
-      authorization_header.should include(%Q(response="#{request_digest}"))
+      expect(authorization_header).to include(%(response="#{request_digest}"))
     end
   end
 end
